==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-share/app/translations/peony-share-extension_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation>Recurso compartido avanzado</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="109"/>
        <source>Samba set user password</source>
        <translation>Samba establece la contraseña de usuario</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="107"/>
        <source>Samba password:</source>
        <translation>Contraseña de Samba:</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Error en la configuración de la contraseña de Samba, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>Tips</source>
        <translation>Consejos</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>El usuario no ha establecido la contraseña de samba. Si necesita iniciar sesión en %1, puede configurarlo en el menú superior derecho del administrador de archivos</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Excepción del servicio de configuración compartida, confirme si hay una operación de configuración compartida en curso o restablezca el recurso compartido.</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Writable</source>
        <translation>Escritura</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Readonly</source>
        <translation>Solo lectura</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Reject</source>
        <translation>Rechazar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="365"/>
        <source>Share permission settings</source>
        <translation>Configuración de permisos de uso compartido</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="377"/>
        <source>delete</source>
        <translation>borrar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="394"/>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="411"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="412"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Extensión de acciones de Peony Qt</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Permitir carpetas compartidas de usuario</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="453"/>
        <source>Share folder</source>
        <translation>Compartir carpeta</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="142"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>La carpeta se comparte actualmente en modo de solo lectura y la configuración del recurso compartido requiere agregar los permisos de escritura de otras personas a la carpeta actual.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="123"/>
        <location filename="../share-page.cpp" line="143"/>
        <location filename="../share-page.cpp" line="197"/>
        <source>question</source>
        <translation>pregunta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="145"/>
        <location filename="../share-page.cpp" line="199"/>
        <source>Confirm adding permissions</source>
        <translation>Confirmar la adición de permisos</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="146"/>
        <location filename="../share-page.cpp" line="200"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <location filename="../share-page.cpp" line="113"/>
        <location filename="../share-page.cpp" line="174"/>
        <location filename="../share-page.cpp" line="183"/>
        <location filename="../share-page.cpp" line="229"/>
        <location filename="../share-page.cpp" line="239"/>
        <location filename="../share-page.cpp" line="283"/>
        <location filename="../share-page.cpp" line="320"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>El nombre del recurso compartido no debe contener %1 y no puede comenzar con un guión (-) o un espacio en blanco, ni terminar con un espacio en blanco.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="113"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>El nombre del recurso compartido no puede ser el mismo que el nombre de usuario actual</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="123"/>
        <source>The share name is already used by other users. You can rename the folder and then set the share.</source>
        <translation>El nombre del recurso compartido ya está siendo utilizado por otros usuarios. Puede cambiar el nombre de la carpeta y, a continuación, establecer el recurso compartido.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="196"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation>La carpeta se comparte actualmente con el conjunto de acceso anónimo, ¿necesito aumentar automáticamente los permisos ejecutables del archivo actual y otros en el directorio antecesor?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="283"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Excepción del servicio de configuración compartida, confirme si hay una operación de configuración compartida en curso o restablezca el recurso compartido.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="295"/>
        <source>Samba set user password</source>
        <translation>Samba establece la contraseña de usuario</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="293"/>
        <source>Samba password:</source>
        <translation>Contraseña de Samba:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="320"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Error en la configuración de la contraseña de Samba, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="421"/>
        <source>usershare</source>
        <translation>Compartir usuario</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="428"/>
        <location filename="../share-page.cpp" line="471"/>
        <source>share this folder</source>
        <translation>Compartir esta carpeta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="428"/>
        <location filename="../share-page.cpp" line="478"/>
        <source>don`t share this folder</source>
        <translation>No compartas esta carpeta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="504"/>
        <source>Share name:</source>
        <translation>Nombre de la acción:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="509"/>
        <source>Read Only</source>
        <translation>Solo lectura</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="512"/>
        <source>Allow Anonymous</source>
        <translation>Permitir anónimo</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="520"/>
        <source>Advanced Sharing</source>
        <translation>Uso compartido avanzado</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="505"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-share/app/translations/peony-share-extension_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="59"/>
        <source>Advanced share</source>
        <translation>Recurso compartido avanzado</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="111"/>
        <source>Samba set user password</source>
        <translation>Samba establece la contraseña de usuario</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="109"/>
        <source>Samba password:</source>
        <translation>Contraseña de Samba:</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="119"/>
        <location filename="../advanced-share-page.cpp" line="131"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="119"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Error en la configuración de la contraseña de Samba, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="127"/>
        <source>Tips</source>
        <translation>Consejos</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="127"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>El usuario no ha establecido la contraseña de samba. Si necesita iniciar sesión en %1, puede configurarlo en el menú superior derecho del administrador de archivos</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="131"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Excepción del servicio de configuración compartida, confirme si hay una operación de configuración compartida en curso o restablezca el recurso compartido.</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Writable</source>
        <translation>Escritura</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Readonly</source>
        <translation>Solo lectura</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Reject</source>
        <translation>Rechazar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="371"/>
        <source>Share permission settings</source>
        <translation>Configuración de permisos de uso compartido</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="383"/>
        <source>delete</source>
        <translation>borrar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="400"/>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="417"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="418"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Extensión de acciones de Peony Qt</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Permitir carpetas compartidas de usuario</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="485"/>
        <source>Share folder</source>
        <translation>Compartir carpeta</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>La carpeta se comparte actualmente en modo de solo lectura y la configuración del recurso compartido requiere agregar los permisos de escritura de otras personas a la carpeta actual.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <location filename="../share-page.cpp" line="145"/>
        <location filename="../share-page.cpp" line="199"/>
        <source>question</source>
        <translation>pregunta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="147"/>
        <location filename="../share-page.cpp" line="201"/>
        <source>Confirm adding permissions</source>
        <translation>Confirmar la adición de permisos</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="148"/>
        <location filename="../share-page.cpp" line="202"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <location filename="../share-page.cpp" line="115"/>
        <location filename="../share-page.cpp" line="176"/>
        <location filename="../share-page.cpp" line="185"/>
        <location filename="../share-page.cpp" line="231"/>
        <location filename="../share-page.cpp" line="241"/>
        <location filename="../share-page.cpp" line="285"/>
        <location filename="../share-page.cpp" line="325"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>El nombre del recurso compartido no debe contener %1 y no puede comenzar con un guión (-) o un espacio en blanco, ni terminar con un espacio en blanco.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="115"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>El nombre del recurso compartido no puede ser el mismo que el nombre de usuario actual</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <source>The share name is already used by other users. You can rename the folder and then set the share.</source>
        <translation>El nombre del recurso compartido ya está siendo utilizado por otros usuarios. Puede cambiar el nombre de la carpeta y, a continuación, establecer el recurso compartido.</translation>
    </message>
    <message>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation type="vanished">La carpeta se comparte actualmente con el conjunto de acceso anónimo, ¿necesito aumentar automáticamente los permisos ejecutables del archivo actual y otros en el directorio antecesor?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="285"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Excepción del servicio de configuración compartida, confirme si hay una operación de configuración compartida en curso o restablezca el recurso compartido.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="297"/>
        <source>Samba set user password</source>
        <translation>Samba establece la contraseña de usuario</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="295"/>
        <source>Samba password:</source>
        <translation>Contraseña de Samba:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="198"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="325"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Error en la configuración de la contraseña de Samba, ¡vuelva a ingresar!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="449"/>
        <source>usershare</source>
        <translation>Compartir usuario</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="456"/>
        <location filename="../share-page.cpp" line="501"/>
        <source>share this folder</source>
        <translation>Compartir esta carpeta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="456"/>
        <location filename="../share-page.cpp" line="508"/>
        <source>don`t share this folder</source>
        <translation>No compartas esta carpeta</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="536"/>
        <source>Share name:</source>
        <translation>Nombre de la acción:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="541"/>
        <source>Allow others to create and delete files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">Solo lectura</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="544"/>
        <source>Allow Anonymous</source>
        <translation>Permitir anónimo</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="553"/>
        <source>Advanced Sharing</source>
        <translation>Uso compartido avanzado</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="537"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
</context>
</TS>
